@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 5                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 1997-2012 The PHP Group                                |
+  | Copyright (c) 1997-2015 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -17,7 +17,7 @@
   |          Dmitry Stogov <dmitry@zend.com>                             |
   +----------------------------------------------------------------------+
 */
-/* $Id: php_http.c 321634 2012-01-01 13:15:04Z felipe $ */
+/* $Id$ */
 
 #include "php_soap.h"
 #include "ext/standard/base64.h"
@@ -32,18 +32,20 @@ static int get_http_headers(php_stream *socketd,char **response, int *out_size T
 	smart_str_appendl(str,const,sizeof(const)-1)
 
 /* Proxy HTTP Authentication */
-void proxy_authentication(zval* this_ptr, smart_str* soap_headers TSRMLS_DC)
+int proxy_authentication(zval* this_ptr, smart_str* soap_headers TSRMLS_DC)
 {
 	zval **login, **password;
 
-	if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_proxy_login", sizeof("_proxy_login"), (void **)&login) == SUCCESS) {
+	if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_proxy_login", sizeof("_proxy_login"), (void **)&login) == SUCCESS &&
+	    Z_TYPE_PP(login) == IS_STRING) {
 		unsigned char* buf;
 		int len;
 		smart_str auth = {0};
 
 		smart_str_appendl(&auth, Z_STRVAL_PP(login), Z_STRLEN_PP(login));
 		smart_str_appendc(&auth, ':');
-		if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_proxy_password", sizeof("_proxy_password"), (void **)&password) == SUCCESS) {
+		if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_proxy_password", sizeof("_proxy_password"), (void **)&password) == SUCCESS &&
+		    Z_TYPE_PP(password) == IS_STRING) {
 			smart_str_appendl(&auth, Z_STRVAL_PP(password), Z_STRLEN_PP(password));
 		}
 		smart_str_0(&auth);
@@ -53,23 +55,27 @@ void proxy_authentication(zval* this_ptr, smart_str* soap_headers TSRMLS_DC)
 		smart_str_append_const(soap_headers, "\r\n");
 		efree(buf);
 		smart_str_free(&auth);
+		return 1;
 	}
+	return 0;
 }
 
 /* HTTP Authentication */
-void basic_authentication(zval* this_ptr, smart_str* soap_headers TSRMLS_DC)
+int basic_authentication(zval* this_ptr, smart_str* soap_headers TSRMLS_DC)
 {
 	zval **login, **password;
 
 	if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_login", sizeof("_login"), (void **)&login) == SUCCESS &&
-			!zend_hash_exists(Z_OBJPROP_P(this_ptr), "_digest", sizeof("_digest"))) {
+	    Z_TYPE_PP(login) == IS_STRING &&
+	    !zend_hash_exists(Z_OBJPROP_P(this_ptr), "_digest", sizeof("_digest"))) {
 		unsigned char* buf;
 		int len;
 		smart_str auth = {0};
 
 		smart_str_appendl(&auth, Z_STRVAL_PP(login), Z_STRLEN_PP(login));
 		smart_str_appendc(&auth, ':');
-		if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_password", sizeof("_password"), (void **)&password) == SUCCESS) {
+		if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_password", sizeof("_password"), (void **)&password) == SUCCESS &&
+		    Z_TYPE_PP(password) == IS_STRING) {
 			smart_str_appendl(&auth, Z_STRVAL_PP(password), Z_STRLEN_PP(password));
 		}
 		smart_str_0(&auth);
@@ -79,6 +85,78 @@ void basic_authentication(zval* this_ptr, smart_str* soap_headers TSRMLS_DC)
 		smart_str_append_const(soap_headers, "\r\n");
 		efree(buf);
 		smart_str_free(&auth);
+		return 1;
+	}
+	return 0;
+}
+
+/* Additional HTTP headers */
+void http_context_headers(php_stream_context* context,
+                          zend_bool has_authorization,
+                          zend_bool has_proxy_authorization,
+                          zend_bool has_cookies,
+                          smart_str* soap_headers TSRMLS_DC)
+{
+	zval **tmp;
+
+	if (context &&
+		php_stream_context_get_option(context, "http", "header", &tmp) == SUCCESS &&
+		Z_TYPE_PP(tmp) == IS_STRING && Z_STRLEN_PP(tmp)) {
+		char *s = Z_STRVAL_PP(tmp);
+		char *p;
+		int name_len;
+
+		while (*s) {
+			/* skip leading newlines and spaces */
+			while (*s == ' ' || *s == '\t' || *s == '\r' || *s == '\n') {
+				s++;
+			}
+			/* extract header name */
+			p = s;
+			name_len = -1;
+			while (*p) {
+				if (*p == ':') {
+					if (name_len < 0) name_len = p - s;
+					break;
+				} else if (*p == ' ' || *p == '\t') {
+					if (name_len < 0) name_len = p - s;
+				} else if (*p == '\r' || *p == '\n') {
+					break;
+				}
+				p++;
+			}
+			if (*p == ':') {
+				/* extract header value */
+				while (*p && *p != '\r' && *p != '\n') {
+					p++;
+				}
+				/* skip some predefined headers */
+				if ((name_len != sizeof("host")-1 ||
+				     strncasecmp(s, "host", sizeof("host")-1) != 0) &&
+				    (name_len != sizeof("connection")-1 ||
+				     strncasecmp(s, "connection", sizeof("connection")-1) != 0) &&
+				    (name_len != sizeof("user-agent")-1 ||
+				     strncasecmp(s, "user-agent", sizeof("user-agent")-1) != 0) &&
+				    (name_len != sizeof("content-length")-1 ||
+				     strncasecmp(s, "content-length", sizeof("content-length")-1) != 0) &&
+				    (name_len != sizeof("content-type")-1 ||
+				     strncasecmp(s, "content-type", sizeof("content-type")-1) != 0) &&
+				    (!has_cookies ||
+				     name_len != sizeof("cookie")-1 ||
+				     strncasecmp(s, "cookie", sizeof("cookie")-1) != 0) &&
+				    (!has_authorization ||
+				     name_len != sizeof("authorization")-1 ||
+				     strncasecmp(s, "authorization", sizeof("authorization")-1) != 0) &&
+				    (!has_proxy_authorization ||
+				     name_len != sizeof("proxy-authorization")-1 ||
+				     strncasecmp(s, "proxy-authorization", sizeof("proxy-authorization")-1) != 0)) {
+				    /* add header */
+					smart_str_appendl(soap_headers, s, p-s);
+					smart_str_append_const(soap_headers, "\r\n");
+				}
+			}
+			s = (*p) ? (p + 1) : p;
+		}
 	}
 }
 
@@ -88,6 +166,7 @@ static php_stream* http_connect(zval* this_ptr, php_url *phpurl, int use_ssl, ph
 	zval **proxy_host, **proxy_port, **tmp;
 	char *host;
 	char *name;
+	char *protocol;
 	long namelen;
 	int port;
 	int old_error_reporting;
@@ -115,10 +194,44 @@ static php_stream* http_connect(zval* this_ptr, php_url *phpurl, int use_ssl, ph
 	old_error_reporting = EG(error_reporting);
 	EG(error_reporting) &= ~(E_WARNING|E_NOTICE|E_USER_WARNING|E_USER_NOTICE);
 
-	namelen = spprintf(&name, 0, "%s://%s:%d", (use_ssl && !*use_proxy)? "ssl" : "tcp", host, port);
+	/* Changed ternary operator to an if/else so that additional comparisons can be done on the ssl_method property */
+	if (use_ssl && !*use_proxy) {
+		if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_ssl_method", sizeof("_ssl_method"), (void **) &tmp) == SUCCESS &&
+			Z_TYPE_PP(tmp) == IS_LONG) {
+			/* uses constants declared in soap.c to determine ssl uri protocol */
+			switch (Z_LVAL_PP(tmp)) {
+				case SOAP_SSL_METHOD_TLS:
+					protocol = "tls";
+					break;
+
+				case SOAP_SSL_METHOD_SSLv2:
+					protocol = "sslv2";
+					break;
+
+				case SOAP_SSL_METHOD_SSLv3:
+					protocol = "sslv3";
+					break;
+
+				case SOAP_SSL_METHOD_SSLv23:
+					protocol = "ssl";
+					break;
+
+				default:
+					protocol = "ssl";
+					break;
+
+			}
+		} else {
+			protocol = "ssl";
+		}
+	} else {
+		protocol = "tcp";
+	}
+
+	namelen = spprintf(&name, 0, "%s://%s:%d", protocol, host, port);
 
 	stream = php_stream_xport_create(name, namelen,
-		ENFORCE_SAFE_MODE | REPORT_ERRORS,
+		REPORT_ERRORS,
 		STREAM_XPORT_CLIENT | STREAM_XPORT_CONNECT,
 		NULL /*persistent_id*/,
 		timeout,
@@ -163,7 +276,34 @@ static php_stream* http_connect(zval* this_ptr, php_url *phpurl, int use_ssl, ph
 		}
 		/* enable SSL transport layer */
 		if (stream) {
-			if (php_stream_xport_crypto_setup(stream, STREAM_CRYPTO_METHOD_SSLv23_CLIENT, NULL TSRMLS_CC) < 0 ||
+			/* if a stream is created without encryption, check to see if SSL method parameter is specified and use
+ 			   proper encrypyion method based on constants defined in soap.c */
+			int crypto_method = STREAM_CRYPTO_METHOD_SSLv23_CLIENT;
+			if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_ssl_method", sizeof("_ssl_method"), (void **) &tmp) == SUCCESS &&
+				Z_TYPE_PP(tmp) == IS_LONG) {
+				switch (Z_LVAL_PP(tmp)) {
+					case SOAP_SSL_METHOD_TLS:
+						crypto_method = STREAM_CRYPTO_METHOD_TLS_CLIENT;
+						break;
+
+					case SOAP_SSL_METHOD_SSLv2:
+						crypto_method = STREAM_CRYPTO_METHOD_SSLv2_CLIENT;
+						break;
+
+					case SOAP_SSL_METHOD_SSLv3:
+						crypto_method = STREAM_CRYPTO_METHOD_SSLv3_CLIENT;
+						break;
+
+					case SOAP_SSL_METHOD_SSLv23:
+						crypto_method = STREAM_CRYPTO_METHOD_SSLv23_CLIENT;
+						break;
+
+					default:
+						crypto_method = STREAM_CRYPTO_METHOD_TLS_CLIENT;
+						break;
+				}
+			}
+			if (php_stream_xport_crypto_setup(stream, crypto_method, NULL TSRMLS_CC) < 0 ||
 			    php_stream_xport_crypto_enable(stream, 1 TSRMLS_CC) < 0) {
 				php_stream_close(stream);
 				stream = NULL;
@@ -235,7 +375,7 @@ int make_http_soap_request(zval  *this_ptr,
 		int kind  = Z_LVAL_PP(tmp) & SOAP_COMPRESSION_DEFLATE;
 
 		if (level > 9) {level = 9;}
-		
+
 	  if ((Z_LVAL_PP(tmp) & SOAP_COMPRESSION_ACCEPT) != 0) {
 			smart_str_append_const(&soap_headers_z,"Accept-Encoding: gzip, deflate\r\n");
 	  }
@@ -262,7 +402,7 @@ int make_http_soap_request(zval  *this_ptr,
 	      n = 3;
 				ZVAL_STRING(&func, "gzencode", 0);
 				smart_str_append_const(&soap_headers_z,"Content-Encoding: gzip\r\n");
-				ZVAL_LONG(params[2], 1);
+				ZVAL_LONG(params[2], 0x1f);
 	    }
 			if (call_user_function(CG(function_table), (zval**)NULL, &func, &retval, n, params TSRMLS_CC) == SUCCESS &&
 			    Z_TYPE(retval) == IS_STRING) {
@@ -294,7 +434,7 @@ int make_http_soap_request(zval  *this_ptr,
 		context = php_stream_context_from_zval(*tmp, 0);
 	}
 
-	if (context && 
+	if (context &&
 		php_stream_context_get_option(context, "http", "max_redirects", &tmp) == SUCCESS) {
 		if (Z_TYPE_PP(tmp) != IS_STRING || !is_numeric_string(Z_STRVAL_PP(tmp), Z_STRLEN_PP(tmp), &redirect_max, NULL, 1)) {
 			if (Z_TYPE_PP(tmp) == IS_LONG)
@@ -387,12 +527,12 @@ try_again:
 
 	if (stream) {
 		zval **cookies, **login, **password;
-	  int ret = zend_list_insert(phpurl, le_url);
+	  int ret = zend_list_insert(phpurl, le_url TSRMLS_CC);
 
 		add_property_resource(this_ptr, "httpurl", ret);
 		/*zend_list_addref(ret);*/
 
-		if (context && 
+		if (context &&
 		    php_stream_context_get_option(context, "http", "protocol_version", &tmp) == SUCCESS &&
 		    Z_TYPE_PP(tmp) == IS_DOUBLE &&
 		    Z_DVAL_PP(tmp) == 1.0) {
@@ -433,12 +573,15 @@ try_again:
 			smart_str_appendc(&soap_headers, ':');
 			smart_str_append_unsigned(&soap_headers, phpurl->port);
 		}
-		if (http_1_1) {
-			smart_str_append_const(&soap_headers, "\r\n"
-				"Connection: Keep-Alive\r\n");
-		} else {
+		if (!http_1_1 ||
+			(zend_hash_find(Z_OBJPROP_P(this_ptr), "_keep_alive", sizeof("_keep_alive"), (void **)&tmp) == SUCCESS &&
+			 (Z_TYPE_PP(tmp) == IS_BOOL || Z_TYPE_PP(tmp) == IS_LONG) &&
+			 Z_LVAL_PP(tmp) == 0)) {
 			smart_str_append_const(&soap_headers, "\r\n"
 				"Connection: close\r\n");
+		} else {
+			smart_str_append_const(&soap_headers, "\r\n"
+				"Connection: Keep-Alive\r\n");
 		}
 		if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_user_agent", sizeof("_user_agent"), (void **)&tmp) == SUCCESS &&
 		    Z_TYPE_PP(tmp) == IS_STRING) {
@@ -447,7 +590,7 @@ try_again:
 				smart_str_appendl(&soap_headers, Z_STRVAL_PP(tmp), Z_STRLEN_PP(tmp));
 				smart_str_append_const(&soap_headers, "\r\n");
 			}
-		} else if (context && 
+		} else if (context &&
 		           php_stream_context_get_option(context, "http", "user_agent", &tmp) == SUCCESS &&
 		           Z_TYPE_PP(tmp) == IS_STRING) {
 			if (Z_STRLEN_PP(tmp) > 0) {
@@ -589,7 +732,7 @@ try_again:
 					PHP_MD5Update(&md5ctx, (unsigned char*)HA2, 32);
 					PHP_MD5Final(hash, &md5ctx);
 					make_digest(response, hash);
-	
+
 					smart_str_append_const(&soap_headers, "Authorization: Digest username=\"");
 					smart_str_appendl(&soap_headers, Z_STRVAL_PP(login), Z_STRLEN_PP(login));
 					if (zend_hash_find(Z_ARRVAL_PP(digest), "realm", sizeof("realm"), (void **)&tmp) == SUCCESS &&
@@ -607,7 +750,7 @@ try_again:
 						smart_str_appends(&soap_headers, phpurl->path);
 					} else {
 						smart_str_appendc(&soap_headers, '/');
-					} 
+					}
 					if (phpurl->query) {
 						smart_str_appendc(&soap_headers, '?');
 						smart_str_appends(&soap_headers, phpurl->query);
@@ -662,14 +805,15 @@ try_again:
 
 		/* Proxy HTTP Authentication */
 		if (use_proxy && !use_ssl) {
-			has_proxy_authorization = 1;
-			proxy_authentication(this_ptr, &soap_headers TSRMLS_CC);
+			has_proxy_authorization = proxy_authentication(this_ptr, &soap_headers TSRMLS_CC);
 		}
 
 		/* Send cookies along with request */
-		if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_cookies", sizeof("_cookies"), (void **)&cookies) == SUCCESS) {
+		if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_cookies", sizeof("_cookies"), (void **)&cookies) == SUCCESS &&
+		    Z_TYPE_PP(cookies) == IS_ARRAY) {
 			zval **data;
 			char *key;
+			uint key_len;
 			int i, n;
 
 			has_cookies = 1;
@@ -678,21 +822,24 @@ try_again:
 				zend_hash_internal_pointer_reset(Z_ARRVAL_PP(cookies));
 				smart_str_append_const(&soap_headers, "Cookie: ");
 				for (i = 0; i < n; i++) {
+					ulong numindx;
+					int res = zend_hash_get_current_key_ex(Z_ARRVAL_PP(cookies), &key, &key_len, &numindx, 0, NULL);
 					zend_hash_get_current_data(Z_ARRVAL_PP(cookies), (void **)&data);
-					zend_hash_get_current_key(Z_ARRVAL_PP(cookies), &key, NULL, FALSE);
 
-					if (Z_TYPE_PP(data) == IS_ARRAY) {
+					if (res == HASH_KEY_IS_STRING && Z_TYPE_PP(data) == IS_ARRAY) {
 					  zval** value;
 
 						if (zend_hash_index_find(Z_ARRVAL_PP(data), 0, (void**)&value) == SUCCESS &&
 						    Z_TYPE_PP(value) == IS_STRING) {
 						  zval **tmp;
 						  if ((zend_hash_index_find(Z_ARRVAL_PP(data), 1, (void**)&tmp) == FAILURE ||
+					           Z_TYPE_PP(tmp) != IS_STRING ||
 						       strncmp(phpurl->path?phpurl->path:"/",Z_STRVAL_PP(tmp),Z_STRLEN_PP(tmp)) == 0) &&
 						      (zend_hash_index_find(Z_ARRVAL_PP(data), 2, (void**)&tmp) == FAILURE ||
+						       Z_TYPE_PP(tmp) != IS_STRING ||
 						       in_domain(phpurl->host,Z_STRVAL_PP(tmp))) &&
 						      (use_ssl || zend_hash_index_find(Z_ARRVAL_PP(data), 3, (void**)&tmp) == FAILURE)) {
-								smart_str_appendl(&soap_headers, key, strlen(key));
+								smart_str_appendl(&soap_headers, key, key_len-1);
 								smart_str_appendc(&soap_headers, '=');
 								smart_str_appendl(&soap_headers, Z_STRVAL_PP(value), Z_STRLEN_PP(value));
 								smart_str_appendc(&soap_headers, ';');
@@ -705,70 +852,12 @@ try_again:
 			}
 		}
 
-		if (context &&
-			php_stream_context_get_option(context, "http", "header", &tmp) == SUCCESS &&
-			Z_TYPE_PP(tmp) == IS_STRING && Z_STRLEN_PP(tmp)) {
-			char *s = Z_STRVAL_PP(tmp);
-			char *p;
-			int name_len;
-
-			while (*s) {
-				/* skip leading newlines and spaces */
-				while (*s == ' ' || *s == '\t' || *s == '\r' || *s == '\n') {
-					s++;
-				}
-				/* extract header name */
-				p = s;
-				name_len = -1;
-				while (*p) {
-					if (*p == ':') {
-						if (name_len < 0) name_len = p - s;
-						break;
-					} else if (*p == ' ' || *p == '\t') {
-						if (name_len < 0) name_len = p - s;
-					} else if (*p == '\r' || *p == '\n') {
-						break;
-					}
-					p++;
-				}
-				if (*p == ':') {
-					/* extract header value */
-					while (*p && *p != '\r' && *p != '\n') {
-						p++;
-					}
-					/* skip some predefined headers */
-					if ((name_len != sizeof("host")-1 ||
-					     strncasecmp(s, "host", sizeof("host")-1) != 0) &&
-					    (name_len != sizeof("connection")-1 ||
-					     strncasecmp(s, "connection", sizeof("connection")-1) != 0) &&
-					    (name_len != sizeof("user-agent")-1 ||
-					     strncasecmp(s, "user-agent", sizeof("user-agent")-1) != 0) &&
-					    (name_len != sizeof("content-length")-1 ||
-					     strncasecmp(s, "content-length", sizeof("content-length")-1) != 0) &&
-					    (name_len != sizeof("content-type")-1 ||
-					     strncasecmp(s, "content-type", sizeof("content-type")-1) != 0) &&
-					    (!has_cookies ||
-					     name_len != sizeof("cookie")-1 ||
-					     strncasecmp(s, "cookie", sizeof("cookie")-1) != 0) &&
-					    (!has_authorization ||
-					     name_len != sizeof("authorization")-1 ||
-					     strncasecmp(s, "authorization", sizeof("authorization")-1) != 0) &&
-					    (!has_proxy_authorization ||
-					     name_len != sizeof("proxy-authorization")-1 ||
-					     strncasecmp(s, "proxy-authorization", sizeof("proxy-authorization")-1) != 0)) {
-					    /* add header */
-						smart_str_appendl(&soap_headers, s, p-s);
-						smart_str_append_const(&soap_headers, "\r\n");
-					}
-				}
-				s = (*p) ? (p + 1) : p;
-			}
-		}
+		http_context_headers(context, has_authorization, has_proxy_authorization, has_cookies, &soap_headers TSRMLS_CC);
 
 		smart_str_append_const(&soap_headers, "\r\n");
 		smart_str_0(&soap_headers);
 		if (zend_hash_find(Z_OBJPROP_P(this_ptr), "trace", sizeof("trace"), (void **) &trace) == SUCCESS &&
-		    Z_LVAL_PP(trace) > 0) {
+		    (Z_TYPE_PP(trace) == IS_BOOL || Z_TYPE_PP(trace) == IS_LONG) && Z_LVAL_PP(trace) != 0) {
 			add_property_stringl(this_ptr, "__last_request_headers", soap_headers.c, soap_headers.len, 1);
 		}
 		smart_str_appendl(&soap_headers, request, request_size);
@@ -813,7 +902,7 @@ try_again:
 		}
 
 		if (zend_hash_find(Z_OBJPROP_P(this_ptr), "trace", sizeof("trace"), (void **) &trace) == SUCCESS &&
-		    Z_LVAL_PP(trace) > 0) {
+		    (Z_TYPE_PP(trace) == IS_BOOL || Z_TYPE_PP(trace) == IS_LONG) && Z_LVAL_PP(trace) != 0) {
 			add_property_stringl(this_ptr, "__last_response_headers", http_headers, http_header_size, 1);
 		}
 
@@ -862,7 +951,8 @@ try_again:
 		char *eqpos, *sempos;
 		zval **cookies;
 
-		if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_cookies", sizeof("_cookies"), (void **)&cookies) == FAILURE) {
+		if (zend_hash_find(Z_OBJPROP_P(this_ptr), "_cookies", sizeof("_cookies"), (void **)&cookies) == FAILURE ||
+		    Z_TYPE_PP(cookies) != IS_ARRAY) {
 			zval *tmp_cookies;
 			MAKE_STD_ZVAL(tmp_cookies);
 			array_init(tmp_cookies);
@@ -973,7 +1063,7 @@ try_again:
 				efree(connection);
 			}
 		}
-	}	
+	}
 
 	if (!get_http_body(stream, http_close, http_headers, &http_body, &http_body_size TSRMLS_CC)) {
 		if (request != buf) {efree(request);}
@@ -1024,7 +1114,7 @@ try_again:
 								strcat(s, new_url->path);
 								efree(new_url->path);
 								new_url->path = s;
-							} 
+							}
 						} else {
 							char *s = emalloc(strlen(new_url->path) + 2);
 							s[0] = '/'; s[1] = 0;
@@ -1143,7 +1233,7 @@ try_again:
 				zval *err;
 				MAKE_STD_ZVAL(err);
 				ZVAL_STRINGL(err, http_body, http_body_size, 1);
-				add_soap_fault(this_ptr, "HTTP", "Didn't recieve an xml document", NULL, err TSRMLS_CC);
+				add_soap_fault(this_ptr, "HTTP", "Didn't receive an xml document", NULL, err TSRMLS_CC);
 				efree(content_type);
 				efree(http_headers);
 				efree(http_body);
@@ -1311,15 +1401,15 @@ static int get_http_body(php_stream *stream, int close, char *headers,  char **r
 	}
 
 	if (header_chunked) {
-		char ch, done, chunk_size[10], headerbuf[8192];
+		char ch, done, headerbuf[8192];
 
 		done = FALSE;
 
 		while (!done) {
 			int buf_size = 0;
 
-			php_stream_gets(stream, chunk_size, sizeof(chunk_size));
-			if (sscanf(chunk_size, "%x", &buf_size) > 0 ) {
+			php_stream_gets(stream, headerbuf, sizeof(headerbuf));
+			if (sscanf(headerbuf, "%x", &buf_size) > 0 ) {
 				if (buf_size > 0) {
 					int len_size = 0;
 
@@ -1386,7 +1476,7 @@ static int get_http_body(php_stream *stream, int close, char *headers,  char **r
 		if (header_length < 0 || header_length >= INT_MAX) {
 			return FALSE;
 		}
-		http_buf = emalloc(header_length + 1);
+		http_buf = safe_emalloc(1, header_length, 1);
 		while (http_buf_size < header_length) {
 			int len_read = php_stream_read(stream, http_buf + http_buf_size, header_length - http_buf_size);
 			if (len_read <= 0) {
